#include <avr/pgmspace.h>       // definitions or keeping constants in program memory
#include "main.h"

// table of POWER codes

#define freq_to_timerval(x) ((F_CPU / x - 1 )/ 2)

const uint16_t philipsTimes[] PROGMEM = {
273,92,
46,92,
46,46,
138,135,
92,46,
46,8547,
45,46,
46,0,
};

const struct IrCode code_philips PROGMEM = {
    freq_to_timerval(34760),
    philipsTimes,
    {
    0x01,
    0x22,
    0x32,
    0x22,
    0x22,
    0x22,
    0x22,
    0x22,
    0x41,
    0x25,
    0x01,
    0x22,
    0x32,
    0x26,
    0x22,
    0x22,
    0x22,
    0x22,
    0x41,
    0x27,
}
};

const uint16_t grundigTimes[] PROGMEM = {
54,270,
54,53,
54,2107,
54,268,
54,109,
105,109,
54,11969,
54,0,
};

const struct IrCode code_grundig PROGMEM = {
    freq_to_timerval(29510),
    grundigTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x11,
    0x23,
    0x45,
    0x11,
    0x11,
    0x11,
    0x63,
    0x45,
    0x11,
    0x11,
    0x11,
    0x7,
}
};

const uint16_t brandtTimes[] PROGMEM = {
49,209,
49,208,
49,466,
49,3581,
49,0,
};

const struct IrCode code_brandt PROGMEM = {
    freq_to_timerval(32450),
    brandtTimes,
    {
    0x01,
    0x22,
    0x11,
    0x12,
    0x22,
    0x12,
    0x31,
    0x12,
    0x21,
    0x11,
    0x22,
    0x21,
    0x24,
}
};

const uint16_t sonyTimes[] PROGMEM = {
245,60,
123,60,
61,60,
61,2759,
61,0,
};

const struct IrCode code_sony PROGMEM = {
    freq_to_timerval(37470),
    sonyTimes,
    {
    0x01,
    0x21,
    0x21,
    0x22,
    0x12,
    0x22,
    0x30,
    0x12,
    0x12,
    0x12,
    0x21,
    0x22,
    0x24,
}
};

const uint16_t panasonicTimes[] PROGMEM = {
358,179,
47,44,
47,133,
47,7661,
358,180,
47,0,
};

const struct IrCode code_panasonic PROGMEM = {
    freq_to_timerval(36090),
    panasonicTimes,
    {
    0x01,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x21,
    0x12,
    0x12,
    0x22,
    0x21,
    0x23,
    0x41,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x11,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x21,
    0x12,
    0x12,
    0x22,
    0x21,
    0x25,
}
};

const uint16_t sharpTimes[] PROGMEM = {
27,194,
27,81,
27,4928,
27,4311,
27,0,
};

const struct IrCode code_sharp PROGMEM = {
    freq_to_timerval(37470),
    sharpTimes,
    {
    0x01,
    0x11,
    0x11,
    0x00,
    0x10,
    0x11,
    0x10,
    0x12,
    0x01,
    0x11,
    0x10,
    0x11,
    0x01,
    0x00,
    0x01,
    0x03,
    0x01,
    0x11,
    0x11,
    0x00,
    0x10,
    0x11,
    0x10,
    0x12,
    0x01,
    0x11,
    0x10,
    0x11,
    0x01,
    0x00,
    0x01,
    0x04,
}
};

const uint16_t samsungTimes[] PROGMEM = {
468,480,
55,175,
55,64,
55,4592,
55,0,
};

const struct IrCode code_samsung PROGMEM = {
    freq_to_timerval(37043),
    samsungTimes,
    {
    0x01,
    0x11,
    0x22,
    0x22,
    0x21,
    0x11,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x11,
    0x11,
    0x13,
    0x01,
    0x11,
    0x22,
    0x22,
    0x21,
    0x11,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x11,
    0x11,
    0x14,
}
};

const uint16_t jvcTimes[] PROGMEM = {
862,431,
53,161,
53,53,
53,2368,
53,2367,
53,0,
};

const struct IrCode code_jvc PROGMEM = {
    freq_to_timerval(37470),
    jvcTimes,
    {
    0x01,
    0x12,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x22,
    0x23,
    0x11,
    0x22,
    0x22,
    0x22,
    0x11,
    0x12,
    0x12,
    0x22,
    0x41,
    0x12,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x22,
    0x25,
}
};

const uint16_t hitachiTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_hitachi PROGMEM = {
    freq_to_timerval(37470),
    hitachiTimes,
    {
    0x01,
    0x11,
    0x12,
    0x12,
    0x12,
    0x22,
    0x21,
    0x21,
    0x22,
    0x22,
    0x12,
    0x11,
    0x11,
    0x11,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t nonamesTimes[] PROGMEM = {
92,92,
184,92,
92,184,
92,9217,
91,92,
92,0,
};

const struct IrCode code_nonames PROGMEM = {
    freq_to_timerval(34800),
    nonamesTimes,
    {
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x13,
    0x41,
    0x00,
    0x00,
    0x00,
    0x20,
    0x15,
}
};

const uint16_t toshiba2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_toshiba2 PROGMEM = {
    freq_to_timerval(37470),
    toshiba2Times,
    {
    0x01,
    0x11,
    0x11,
    0x12,
    0x12,
    0x22,
    0x22,
    0x21,
    0x21,
    0x21,
    0x12,
    0x11,
    0x12,
    0x12,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t goodmansTimes[] PROGMEM = {
924,462,
56,174,
56,56,
56,4055,
926,230,
56,9857,
56,0,
};

const struct IrCode code_goodmans PROGMEM = {
    freq_to_timerval(37470),
    goodmansTimes,
    {
    0x01,
    0x22,
    0x21,
    0x12,
    0x21,
    0x22,
    0x12,
    0x21,
    0x21,
    0x12,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x22,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t aiwaTimes[] PROGMEM = {
920,430,
56,175,
56,59,
56,2362,
921,460,
56,0,
};

const struct IrCode code_aiwa PROGMEM = {
    freq_to_timerval(37430),
    aiwaTimes,
    {
    0x01,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x13,
    0x41,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x15,
}
};

const uint16_t daewooTimes[] PROGMEM = {
822,409,
51,52,
51,163,
51,409,
51,2397,
51,0,
};

const struct IrCode code_daewoo PROGMEM = {
    freq_to_timerval(37470),
    daewooTimes,
    {
    0x01,
    0x12,
    0x12,
    0x11,
    0x13,
    0x21,
    0x21,
    0x21,
    0x11,
    0x40,
    0x11,
    0x21,
    0x21,
    0x11,
    0x32,
    0x12,
    0x12,
    0x11,
    0x15,
}
};

const uint16_t NApioneerTimes[] PROGMEM = {
876,435,
56,54,
56,159,
56,2610,
877,434,
56,0,
};

const struct IrCode code_pioneer PROGMEM = {
    freq_to_timerval(37470),
    NApioneerTimes,
    {
    0x01,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x41,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x41,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x25,
}
};

const uint16_t mitsubishiTimes[] PROGMEM = {
31,216,
31,218,
31,92,
31,2844,
31,0,
};

const struct IrCode code_mitsubishi PROGMEM = {
    freq_to_timerval(32450),
    mitsubishiTimes,
    {
    0x01,
    0x12,
    0x22,
    0x12,
    0x21,
    0x22,
    0x22,
    0x22,
    0x31,
    0x11,
    0x22,
    0x21,
    0x22,
    0x12,
    0x22,
    0x22,
    0x24,
}
};

const uint16_t sanyoTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_sanyo PROGMEM = {
    freq_to_timerval(37470),
    sanyoTimes,
    {
    0x01,
    0x11,
    0x22,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t acuraTimes[] PROGMEM = {
868,427,
53,53,
53,161,
53,428,
53,2507,
868,428,
52,0,
};

const struct IrCode code_acura PROGMEM = {
    freq_to_timerval(37470),
    acuraTimes,
    {
    0x01,
    0x21,
    0x11,
    0x11,
    0x13,
    0x12,
    0x22,
    0x11,
    0x11,
    0x45,
    0x12,
    0x11,
    0x11,
    0x11,
    0x31,
    0x22,
    0x21,
    0x11,
    0x16,
}
};

const uint16_t radiolaTimes[] PROGMEM = {
51,307,
51,1026,
51,309,
51,667,
51,3079,
51,0,
};

const struct IrCode code_radiola PROGMEM = {
    freq_to_timerval(34800),
    radiolaTimes,
    {
    0x01,
    0x21,
    0x21,
    0x22,
    0x22,
    0x22,
    0x22,
    0x23,
    0x42,
    0x12,
    0x12,
    0x12,
    0x22,
    0x22,
    0x22,
    0x22,
    0x35,
}
};

const uint16_t magnavoxTimes[] PROGMEM = {
924,462,
56,174,
56,56,
56,4055,
926,230,
56,9857,
54,0,
};

const struct IrCode code_magnavox PROGMEM = {
    freq_to_timerval(37470),
    magnavoxTimes,
    {
    0x01,
    0x12,
    0x22,
    0x22,
    0x12,
    0x12,
    0x11,
    0x11,
    0x22,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t hitachi3Times[] PROGMEM = {
924,464,
58,173,
58,57,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_hitachi3 PROGMEM = {
    freq_to_timerval(37470),
    hitachi3Times,
    {
    0x01,
    0x12,
    0x21,
    0x21,
    0x22,
    0x21,
    0x12,
    0x12,
    0x11,
    0x11,
    0x21,
    0x22,
    0x22,
    0x22,
    0x12,
    0x11,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t necTimes[] PROGMEM = {
918,460,
56,60,
56,178,
56,4582,
921,229,
56,9707,
55,0,
};

const struct IrCode code_nec PROGMEM = {
    freq_to_timerval(37470),
    necTimes,
    {
    0x01,
    0x11,
    0x22,
    0x11,
    0x11,
    0x11,
    0x22,
    0x11,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x21,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t granadaTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_granada PROGMEM = {
    freq_to_timerval(37430),
    granadaTimes,
    {
    0x01,
    0x11,
    0x22,
    0x21,
    0x12,
    0x22,
    0x11,
    0x12,
    0x21,
    0x11,
    0x12,
    0x11,
    0x12,
    0x22,
    0x21,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t asaTimes[] PROGMEM = {
53,255,
53,102,
105,51,
53,51,
53,2439,
53,256,
105,102,
53,12337,
53,0,
};

const struct IrCode code_asa PROGMEM = {
    freq_to_timerval(30460),
    asaTimes,
    {
    0x01,
    0x23,
    0x33,
    0x45,
    0x16,
    0x33,
    0x37,
    0x51,
    0x63,
    0x33,
    0x8,
}
};

const uint16_t samsung2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_samsung2 PROGMEM = {
    freq_to_timerval(37470),
    samsung2Times,
    {
    0x01,
    0x21,
    0x21,
    0x21,
    0x22,
    0x12,
    0x12,
    0x12,
    0x12,
    0x12,
    0x11,
    0x12,
    0x21,
    0x21,
    0x22,
    0x21,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t dumontTimes[] PROGMEM = {
54,272,
54,55,
54,2108,
54,270,
54,111,
105,56,
54,12444,
54,0,
};

const struct IrCode code_dumont PROGMEM = {
    freq_to_timerval(29510),
    dumontTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x11,
    0x23,
    0x41,
    0x54,
    0x11,
    0x11,
    0x63,
    0x41,
    0x54,
    0x11,
    0x11,
    0x7,
}
};

const uint16_t novatronicTimes[] PROGMEM = {
54,255,
54,99,
107,48,
54,49,
54,1482,
54,256,
107,99,
54,11310,
54,0,
};

const struct IrCode code_novatronic PROGMEM = {
    freq_to_timerval(33600),
    novatronicTimes,
    {
    0x01,
    0x23,
    0x33,
    0x33,
    0x33,
    0x33,
    0x33,
    0x34,
    0x51,
    0x32,
    0x13,
    0x33,
    0x63,
    0x33,
    0x33,
    0x75,
    0x13,
    0x21,
    0x33,
    0x36,
    0x33,
    0x33,
    0x38,
}
};

const uint16_t lgTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_lg PROGMEM = {
    freq_to_timerval(37470),
    lgTimes,
    {
    0x01,
    0x12,
    0x11,
    0x11,
    0x12,
    0x21,
    0x22,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t jvc2Times[] PROGMEM = {
862,431,
56,163,
56,53,
56,1741,
56,0,
};

const struct IrCode code_jvc2 PROGMEM = {
    freq_to_timerval(37430),
    jvc2Times,
    {
    0x01,
    0x11,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x21,
    0x13,
    0x11,
    0x11,
    0x12,
    0x22,
    0x11,
    0x12,
    0x12,
    0x11,
    0x31,
    0x11,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x21,
    0x14,
}
};

const uint16_t thomsonTimes[] PROGMEM = {
52,209,
52,466,
52,3788,
52,0,
};

const struct IrCode code_thomson PROGMEM = {
    freq_to_timerval(32520),
    thomsonTimes,
    {
    0x00,
    0x11,
    0x00,
    0x01,
    0x11,
    0x00,
    0x20,
    0x01,
    0x10,
    0x00,
    0x11,
    0x10,
    0x03,
}
};

const uint16_t siemensTimes[] PROGMEM = {
53,152,
53,354,
53,151,
53,3014,
53,0,
};

const struct IrCode code_siemens PROGMEM = {
    freq_to_timerval(37430),
    siemensTimes,
    {
    0x01,
    0x11,
    0x22,
    0x32,
    0x11,
    0x12,
    0x24,
}
};

const uint16_t nec2Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_nec2 PROGMEM = {
    freq_to_timerval(37470),
    nec2Times,
    {
    0x01,
    0x11,
    0x22,
    0x11,
    0x12,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t adventTimes[] PROGMEM = {
92,92,
184,92,
92,184,
92,9217,
92,0,
};

const struct IrCode code_advent PROGMEM = {
    freq_to_timerval(34800),
    adventTimes,
    {
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x13,
    0x01,
    0x00,
    0x00,
    0x00,
    0x20,
    0x14,
}
};

const uint16_t triumphTimes[] PROGMEM = {
924,464,
58,173,
58,57,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_triumph PROGMEM = {
    freq_to_timerval(37470),
    triumphTimes,
    {
    0x01,
    0x22,
    0x21,
    0x11,
    0x22,
    0x11,
    0x12,
    0x22,
    0x12,
    0x22,
    0x12,
    0x22,
    0x21,
    0x11,
    0x21,
    0x11,
    0x13,
    0x45,
    0x46,
}
};

const uint16_t NAfujitsuTimes[] PROGMEM = {
15,690,
15,691,
15,456,
15,4705,
15,0,
};

const struct IrCode code_fujitsu PROGMEM = {
    freq_to_timerval(38970),
    NAfujitsuTimes,
    {
    0x01,
    0x11,
    0x12,
    0x21,
    0x12,
    0x23,
    0x11,
    0x11,
    0x12,
    0x21,
    0x12,
    0x24,
}
};

const uint16_t blueskyTimes[] PROGMEM = {
358,358,
89,90,
89,269,
89,3492,
359,358,
89,0,
};

const struct IrCode code_bluesky PROGMEM = {
    freq_to_timerval(34800),
    blueskyTimes,
    {
    0x01,
    0x22,
    0x12,
    0x11,
    0x21,
    0x21,
    0x12,
    0x11,
    0x21,
    0x22,
    0x12,
    0x12,
    0x23,
    0x41,
    0x22,
    0x12,
    0x11,
    0x21,
    0x21,
    0x12,
    0x11,
    0x21,
    0x22,
    0x12,
    0x12,
    0x25,
}
};

const uint16_t phonolaTimes[] PROGMEM = {
49,306,
52,1022,
52,304,
52,663,
52,3137,
52,0,
};

const struct IrCode code_phonola PROGMEM = {
    freq_to_timerval(32480),
    phonolaTimes,
    {
    0x01,
    0x21,
    0x21,
    0x23,
    0x33,
    0x32,
    0x24,
    0x21,
    0x21,
    0x21,
    0x23,
    0x33,
    0x32,
    0x25,
}
};

const uint16_t firstlineTimes[] PROGMEM = {
924,462,
56,56,
56,174,
56,4055,
926,230,
56,9857,
56,0,
};

const struct IrCode code_firstline PROGMEM = {
    freq_to_timerval(37470),
    firstlineTimes,
    {
    0x01,
    0x11,
    0x11,
    0x11,
    0x22,
    0x22,
    0x21,
    0x22,
    0x11,
    0x21,
    0x21,
    0x11,
    0x12,
    0x12,
    0x12,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t toshiba4Times[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9881,
58,0,
};

const struct IrCode code_toshiba4 PROGMEM = {
    freq_to_timerval(37430),
    toshiba4Times,
    {
    0x01,
    0x11,
    0x21,
    0x12,
    0x12,
    0x22,
    0x12,
    0x21,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t acerTimes[] PROGMEM = {
924,464,
58,57,
58,173,
58,4054,
926,230,
58,9880,
58,0,
};

const struct IrCode code_acer PROGMEM = {
    freq_to_timerval(37470),
    acerTimes,
    {
    0x01,
    0x11,
    0x11,
    0x22,
    0x12,
    0x22,
    0x22,
    0x11,
    0x22,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t viewsonicTimes[] PROGMEM = {
924,461,
56,56,
56,174,
56,4055,
926,230,
56,9855,
56,0,
};

const struct IrCode code_viewsonic PROGMEM = {
    freq_to_timerval(37470),
    viewsonicTimes,
    {
    0x01,
    0x11,
    0x12,
    0x12,
    0x12,
    0x12,
    0x21,
    0x21,
    0x21,
    0x11,
    0x11,
    0x11,
    0x12,
    0x22,
    0x22,
    0x22,
    0x23,
    0x45,
    0x46,
}
};

const uint16_t tvbgone4Times[] PROGMEM = {
	27, 77,
	25, 80,
	25, 187,
	26, 4187,
	25, 4786,
	25, 0,
};

const struct IrCode code_tvbgone4 PROGMEM = {
	freq_to_timerval(38885),
	tvbgone4Times,
	{
	0x20,
	0x01,
	0x00,
	0x22,
	0x02,
	0x01,
	0x02,
	0x04,
	0x20,
	0x01,
	0x02,
	0x01,
	0x21,
	0x22,
	0x20,
	0x23,
	0x20,
	0x01,
	0x00,
	0x22,
	0x02,
	0x01,
	0x02,
	0x04,
	0x20,
	0x01,
	0x02,
	0x01,
	0x21,
	0x22,
	0x20,
	0x25,
	}
};

const uint16_t newfujitsu3Times[] PROGMEM = {
23,111,
23,43,
23,21,
46,21,
23,5338,
23,0,
};

const struct IrCode code_newfujitsu3 PROGMEM = {
    freq_to_timerval(37470), //NOT SURE
    newfujitsu3Times,
    {
    0x01,
    0x23,
    0x21,
    0x22,
    0x24,
    0x01,
    0x23,
    0x21,
    0x22,
    0x25,
}
};

const uint16_t code23Times[] PROGMEM = {
39,38,
39,1,
39,76,
39,39,
39,3947,
78,38,
39,0,
};

const struct IrCode code_code23 PROGMEM = {
    freq_to_timerval(37470), //NOT SURE
    code23Times,
    {
    0x00,
    0x10,
    0x00,
    0x00,
    0x02,
    0x01,
    0x34,
    0x00,
    0x50,
    0x00,
    0x00,
    0x20,
    0x10,
    0x6,
}
};

const uint16_t code10Times[] PROGMEM = {
371,183,
23,23,
23,70,
23,187,
23,1096,
371,184,
23,0,
};

const struct IrCode code_code10 PROGMEM = {
    freq_to_timerval(37470), //NOT SURE
    code10Times,
    {
    0x01,
    0x21,
    0x11,
    0x11,
    0x13,
    0x12,
    0x22,
    0x11,
    0x11,
    0x45,
    0x12,
    0x11,
    0x11,
    0x11,
    0x31,
    0x22,
    0x21,
    0x11,
    0x16,
}
};

const uint16_t RCATimes[] PROGMEM = {
394,200,
25,24,
24,24,
24,77,
25,77,
25,23,
24,1804,
394,99,
25,4140,
394,100,
24,0,
};

const struct IrCode code_RCA PROGMEM = {
    freq_to_timerval(37470), //NOT SURE
    RCATimes,
    {
    0x01,
    0x22,
    0x34,
    0x32,
    0x54,
    0x33,
    0x51,
    0x23,
    0x42,
    0x23,
    0x43,
    0x22,
    0x13,
    0x32,
    0x12,
    0x33,
    0x46,
    0x78,
    0x9A,
}
};

const uint16_t CETimes[] PROGMEM = {
14,365,
14,241,
14,242,
13,242,
14,2250,
14,0,
};

const struct IrCode code_CE PROGMEM = {
    freq_to_timerval(37470), //NOT SURE
    CETimes,
    {
    0x01,
    0x00,
    0x02,
    0x00,
    0x03,
    0x04,
    0x02,
    0x00,
    0x01,
    0x00,
    0x02,
    0x05,
}
};

const uint16_t lg2Times[] PROGMEM = {
371,183,
24,70,
23,23,
24,22,
24,23,
24,21,
23,187,
23,70,
23,1095,
23,0,
};

const struct IrCode code_lg2 PROGMEM = {
    freq_to_timerval(37470),
    lg2Times,
    {
    0x01,
    0x23,
    0x42,
    0x23,
    0x56,
    0x31,
    0x71,
    0x22,
    0x34,
    0x80,
    0x12,
    0x24,
    0x22,
    0x25,
    0x62,
    0x17,
    0x12,
    0x22,
    0x49,
}
};


// CODES NA
// CODES NA
// CODES NA

// Pioneer, Sansui, Toshiba
const uint16_t pioneerTimes[] PROGMEM = {
	59, 59,
	59, 173,
	926, 461,
	59, 4117,
	59, 0,
};

const struct IrCode NApioneerCode PROGMEM = {
	freq_to_timerval(37470),
	pioneerTimes,
	{
		0x21,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x10,
		0x10,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x13,
		0x21,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x10,
		0x00,
		0x10,
		0x10,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x10,
		0x14,
	}
};

// Sylvania
const uint16_t sylvaniaTimes[] PROGMEM = {
	56, 56,
	56, 174,
	926, 230,
	924, 461,
	56, 4055,
	56, 9855,
	56, 0,
};

const struct IrCode NAsylvaniaCode PROGMEM = {
	freq_to_timerval(37430),
	sylvaniaTimes,
	{
		0x31,
		0x11,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x11,
		0x11,
		0x11,
		0x11,
		0x00,
		0x04,
		0x25,
		0x26,
	}
};

// Pioneer, Hitachi
const uint16_t pioneer2Times[] PROGMEM = {
	53, 55,
	53, 164,
	873, 440,
	53, 2633,
	53, 0,
};

const struct IrCode NApioneer2Code PROGMEM = {
	freq_to_timerval(37470),
	pioneer2Times,
	{
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x13,
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x13,
		0x20,
		0x10,
		0x10,
		0x10,
		0x11,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x11,
		0x00,
		0x01,
		0x10,
		0x00,
		0x14,
	}
};

// Fujitsu
const uint16_t fujitsuTimes[] PROGMEM = {
	43, 42,
	43, 126,
	336, 166,
	43, 4723,
	43, 0,
};

const struct IrCode NAfujitsuCode PROGMEM = {
	freq_to_timerval(37470),
	fujitsuTimes,
	{
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x00,
		0x03,
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x00,
		0x00,
		0x04,
	}
};

// Thomson
const uint16_t NAthomsonTimes[] PROGMEM = {
	52, 102,
	52, 205,
	411, 410,
	52, 821,
	51, 0,
};

const struct IrCode NAthomsonCode PROGMEM = {
	freq_to_timerval(55600),
	NAthomsonTimes,
	{
		0x20,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x13,
		0x20,
		0x11,
		0x10,
		0x01,
		0x01,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x10,
		0x10,
		0x14,
	}
};

// Fujitsu
const uint16_t fujitsu2Times[] PROGMEM = {
	43, 43,
	43, 124,
	346, 158,
	43, 5438,
	43, 0,
};

const struct IrCode NAfujitsu2Code PROGMEM = {
	freq_to_timerval(37470),
	fujitsu2Times,
	{
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x03,
		0x20,
		0x01,
		0x01,
		0x00,
		0x01,
		0x10,
		0x00,
		0x11,
		0x00,
		0x00,
		0x00,
		0x00,
		0x00,
		0x01,
		0x00,
		0x00,
		0x10,
		0x10,
		0x10,
		0x00,
		0x10,
		0x00,
		0x00,
		0x00,
		0x04,
	}
};

// AOC, NEC
const uint16_t aoc2Times[] PROGMEM = {
	170, 166,
	530, 167,
	42, 269,
	42, 0,
};

const struct IrCode NAaoc2Code PROGMEM = {
	freq_to_timerval(40580),
	aoc2Times,
	{
		0x12,
		0x22,
		0x02,
		0x00,
		0x22,
		0x30
	}
};

// Contec/Cony, Hitachi, JVC, Sears, Teknika
const uint16_t contec3Times[] PROGMEM = {
	136, 45,
	46, 123,
	46, 3583,
	46, 0,
};

const struct IrCode NAcontec3Code PROGMEM = {
	freq_to_timerval(39010),
	contec3Times,
	{
		0x11,
		0x11,
		0x10,
		0x11,
		0x11,
		0x12,
		0x11,
		0x11,
		0x10,
		0x11,
		0x11,
		0x13,
	}
};

// JVC
const uint16_t NAjvc2Times[] PROGMEM = {
	59, 57,
	59, 178,
	924, 231,
	924, 459,
	59, 4260,
	59, 9752,
	59, 0,
};

const struct IrCode NAjvc2Code PROGMEM = {
	freq_to_timerval(38970),
	NAjvc2Times,
	{
		0x30,
		0x01,
		0x00,
		0x01,
		0x11,
		0x10,
		0x11,
		0x10,
		0x00,
		0x00,
		0x11,
		0x00,
		0x01,
		0x11,
		0x00,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};

// JVC
const struct IrCode NAjvc3Code PROGMEM = {
	freq_to_timerval(38970),
	jvc2Times,
	{
		0x31,
		0x11,
		0x01,
		0x10,
		0x00,
		0x00,
		0x10,
		0x01,
		0x10,
		0x10,
		0x01,
		0x00,
		0x01,
		0x01,
		0x10,
		0x11,
		0x14,
		0x25,
		0x26,
	}
};



const PGM_P *powerCodes[] PROGMEM  = {
//58 Codes = 44.6%
//Failures: Hantronix (moniteur ?), Bosch (moniteur), Fujitsu pro, NEC
&code_philips, //DUP OK
&code_sony, //DUP OK
&code_samsung, //DUP OK
&code_samsung2, //DUP OK
&code_panasonic, //DUP OK
&code_sharp, //DUP OK
&code_lg, //DUP OK
&code_lg2, //DUP OK
&code_fujitsu,
&code_newfujitsu3, //DUP OK

&NAfujitsuCode,
&NAfujitsu2Code,
&code_sanyo, //Fabrique des chassis gnriques chez les chinois
&code_code23, //DUP OK
&code_nonames, //DUP OK
&code_tvbgone4, //DUP OK
&code_thomson, //DUP OK
&code_toshiba2, //Fabrique des chassis gnriques chez les chinois
&code_toshiba4, //DUP OK
&NAthomsonCode, //DUP OK

&code_nec, //DUP OK
&code_nec2, //DUP OK
&code_grundig, //DUP OK
&code_code10, //DUP OK
&code_acer, //DUP OK
&code_brandt, //DUP OK
&code_CE, //Continental Edison
&NAjvc2Code,
&NAjvc3Code,
&code_jvc, //DUP OK

&code_jvc2, //DUP OK
&code_bluesky, //DUP OK
&code_hitachi,
&code_hitachi3,
&code_firstline, //DUP OK
&code_mitsubishi,
&code_siemens,
&code_pioneer,
&NApioneerCode,
&NApioneer2Code,

&code_viewsonic, //DUP OK
&NAsylvaniaCode,
&code_advent,
&code_triumph, //DUP OK
&code_acura,
&code_radiola,
&code_magnavox,
&code_RCA,
&NAaoc2Code,
&NAcontec3Code,

&code_goodmans,
&code_aiwa,
&code_daewoo,
&code_phonola, //DUP OK
&code_granada,
&code_asa, //DUP OK
&code_dumont,
&code_novatronic,
};

uint8_t num_codes = (sizeof(powerCodes)/sizeof(*powerCodes));
