/*
TV-B-Gone
Firmware
for use with ATtiny85
Mitch Altman + Limor Fried
7-Oct-07

Added double-click loop mode
Furrtek
9-Dec-07

MODE CHIANT/OU PAS ok
MODE CONNU/POURRI todo
INTERLACE ?

Modified for v1.1, added Continental Edison and LG codes.

Distributed under Creative Commons 2.5 -- Attib & Share Alike
*/

/*
Usage:
One click (re)starts scanning, then puts AtTiny85 asleep.
A double-click loops scanning forever, AtTiny85 is put asleep with a "long" click.
Activate loop mode, hide the kit and see how it's annoying :)
Todo:
*/

#include <avr/io.h>             // this contains all the IO port definitions
#include <avr/interrupt.h>      // definitions for interrupts
#include <avr/sleep.h>          // definitions for power-down modes
#include <avr/pgmspace.h>       // definitions or keeping constants in program memory
#include "EUCodesCX.c"			// temporary European database

#define LED PB0         		// visible LED
#define IRLED PB1       		// IR LED
#define BUTTON PB2      		// push button

uint8_t Loop=0;

#define NOP __asm__ __volatile__ ("nop")
#define DELAY_CNT 11
void delay_ten_us(uint16_t us) {
  uint8_t timer;
  while (us != 0) {
    for (timer=0; timer <= DELAY_CNT; timer++) {
      NOP;
      NOP;
    }
    NOP;
    us--;
  }
}

void gotosleep( void ) {
  // Shut down everything and put the CPU to sleep
  TCCR1 = 0;                      // turn off frequency generator (should be off already)
  PORTB = _BV(BUTTON) | _BV(LED); // turn on the button pullup, turn off visible LED
  PORTB &= ~_BV(IRLED);           // turn off IR LED
  delay_ten_us(1000);             // wait 10 millisec second
  MCUCR = _BV(SM1) |  _BV(SE);    // power down mode,  SE=1 (bit 5) -- enables Sleep Modes
  sleep_cpu();                    // put CPU inteo Power Down Sleep Mode
}

SIGNAL(SIG_INTERRUPT0) {
  delay_ten_us(2500);
  while((PINB & _BV(BUTTON))==0);
  delay_ten_us(2500);
  //if (Loop==1) {
  //gotosleep();
  //} else {
  PORTB &= ~_BV(LED); // turn on visible LED at PB0 by pulling pin to ground
  TCCR1 = 0;          // turn off Timer1 frequency generator (should be off already)
  WDTCR = _BV(WDE);   // turn on the watchdog timer to reset the chip
  //}
}

void quickflashLED( void ) {
  PORTB &= ~_BV(LED);         // turn on visible LED at PB0 by pulling pin to ground
  delay_ten_us(1000);         // 30 millisec delay
  PORTB |= _BV(LED);          // turn off visible LED at PB0 by pulling pin to +3V
}

void quicklowLED( void ) {
  PORTB |= _BV(LED);          // turn off visible LED at PB0 by pulling pin to +3V
  delay_ten_us(7000);         // 30 millisec delay
  PORTB &= ~_BV(LED);         // turn on visible LED at PB0 by pulling pin to ground
}

void quickflashLED4x( void ) {
  quickflashLED();
  delay_ten_us(8000);        // 80 millisec delay
  quickflashLED();
  delay_ten_us(8000);        // 80 millisec delay
  quickflashLED();
  delay_ten_us(8000);        // 80 millisec delay
  quickflashLED();
  delay_ten_us(8000);        // 80 millisec delay
  quickflashLED();
}

void xmitCodeElement(uint16_t ontime, uint16_t offtime ) {
  // start Timer1 outputting the carrier frequency to IR emitters on OC1A (PB1, pin 6)
  TCCR1 = _BV(COM1A0) | _BV(CS10) | _BV(CTC1);
  //TCCR1 = 0b10010001  // CTC1 = 1 to reset Timer1 to 0 when it reaches the value in OCR1C (i.e., on Compare Match)
                        // PWM1A = 0 to disable PWM mode
                        // COM1A1:0 = 01 to toggle OC1A on Compare Match
                        // CS13:10 = 0001 to start Timer1 with prescaler set to divide by 1 (i.e., no prescaler divide)

  // keep transmitting carrier for onTime
  delay_ten_us(ontime);

  TCCR1 = 0;      // stop Timer1
  delay_ten_us(offtime);
  PORTB &= ~_BV(IRLED);           // turn off IR LED
}

extern const PGM_P *powerCodes[] PROGMEM;

extern uint8_t num_codes;

int main(void) {
  MCUSR = 0;                     // clear watchdog flag
  WDTCR = _BV(WDCE) | _BV(WDE);  // enable WDT disable
  WDTCR = 0;                     // disable WDT

  GIMSK = _BV(INT0);     			// generate an interrupt on low level of INT0
  TIMSK = 0x00;           			// no Timer interrupts enabled

  DDRB = _BV(LED) | _BV(IRLED);    // set the visible and IR LED pins to outputs
  PORTB = _BV(BUTTON) | _BV(LED);  // button has a pullup, visible LED is off when pin is high
  PORTB &= ~_BV(IRLED);            // IR LED is off when pin is low

  delay_ten_us(500);  		       //Debounce the switch

  uint8_t i=0;
  uint8_t Loop=0;
  for(i=0;i<20;i++)	   			//Wait 500 ms for a second button press.
  {
  	  delay_ten_us(2500);
  	  if((PINB & _BV(BUTTON))==0)
  	  {
  	  	  delay_ten_us(1000);  		//Debounce the switch
  	  	  if((PINB & _BV(BUTTON))==0)
  	  	  {
              Loop=1;
  	  	  	  while((PINB & _BV(BUTTON))==0);
			  PORTB &= ~_BV(LED);    // turn on visible LED at PB0 by pulling pin to ground
  	  	      delay_ten_us(65000);   //Debounce the switch release
			  PORTB |= _BV(LED);     // turn off visible LED at PB0 by pulling pin to +3V
  	  	  	  break;
  	  	  }
  	  }
  }
  sei();                 			// turn on INT0 interrupts

  do {
  for(i=0; i<num_codes; i++) {   // for every POWER code in our collection
 	if (Loop) {
	  quickflashLED();
	} else {
	  quicklowLED();
    }
    PGM_P code_ptr = (PGM_P)pgm_read_word(powerCodes+i);     // point to next POWER code

	// get carrier period
    const uint8_t freq = pgm_read_byte(code_ptr++);
    // set OCR for Timer1 to output this POWER code's carrier frequency
    OCR1C = freq; 

	// get pointer to pulse times array
	const PGM_P time_ptr = (PGM_P)pgm_read_word(code_ptr);
	code_ptr+=2;

    // transmit all codeElements for this POWER code (a codeElement is an onTime and an offTime)
    // transmitting onTime means pulsing the IR emitters at the carrier frequency for the length of time specified in onTime
    // transmitting offTime means no output from the IR emitters for the length of time specified in offTime
    uint8_t j = 0;  // index into pulse time array index nibbles
    uint16_t ontime, offtime;
    do {
	  uint8_t ti;
	  // test for even/odd time to determine which nibble to use
	  if(j&1)
		  // get time index low nibble * 4, increment pointer
		  ti = ( pgm_read_byte(code_ptr++) << 2 ) & 0x3C;
	  else
		  // get time index high nibble * 4
		  ti = ( pgm_read_byte(code_ptr) >> 2 ) & 0x3C;

      // read the onTime and offTime from the program memory
      ontime = pgm_read_word(time_ptr+ti);
      offtime = pgm_read_word(time_ptr+ti+2);

      xmitCodeElement(ontime, offtime);  // transmit this codeElement (ontime and offtime)
      j++;
    } while ( offtime != 0 );  // offTime = 0 signifies last codeElement for a POWER code

    // delay 170 milliseconds before transmitting next POWER code
    delay_ten_us(10000); //17000 1000tropbas 4000tropbas test:10000
   }
  } while (Loop==1);

  delay_ten_us(65500); 	  // wait maxtime 
  quickflashLED4x();

  gotosleep();
}
